<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */

namespace App\Http\Controllers\Admin\Post;

use App\Http\Controllers\Controller;
use App\Jobshunt\Models\Image;
use App\Jobshunt\Models\Post;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Yajra\Datatables\Datatables;

class PostController extends Controller
{
    /**
     * @param Request $request
     * @return View
     */
    public function getIndex(Request $request)
    {
        $title = sprintf('List of %s posts', ucfirst($request->get('type')));
        $type = $request->get('type');

        return view('admin.post.index', compact('title', 'type'));
    }


    /**
     * @return mixed
     */
    public function getData(Request $request)
    {
        $posts = Post::select([
            'posts.*',
            DB::raw('users.fullname as fullname'),
        ])->leftJoin('users', 'users.id', '=', 'posts.user_id')
            ->groupBy('posts.id');

        switch ($request->get('type')) {
            case 'expired':
                $posts->where('expire_at', '<=', Carbon::now()->subDays(60));
                break;
            default:
                $posts->approved();
                break;
        }

        $datatables = Datatables::of($posts);

        if ($request->get('type') == 'expired') {
            $datatables->addColumn('actions', function ($post) {
                return '<a href="#" class="image-approve btn btn-success" data-approve="' . $post->id . '"><i class="fa fa-check"></i> Re-Approve </a>
                 <a href="' . route('admin.posts.edit', [$post->id]) . '" class="btn btn-info" target="_blank"><i class="fa fa-edit"></i> Edit </a>
                <a href="#" class="image-disapprove btn btn-danger" data-disapprove="' . $post->id . '"><i class="fa fa-times"></i> Delete</a>';
            });
        } else {
            $datatables->addColumn('actions', function ($post) {
                return '<a href="' . route('admin.posts.edit', [$post->id]) . '" class="btn btn-info" target="_blank"><i class="fa fa-edit"></i> Edit </a>
                <a href="' . route('posts.main', [$post->id, $post->slug]) . '" class="btn btn-success" target="_blank"><i class="fa fa-search"></i> View</a>';
            });
        }

        return $datatables->editColumn('created_at', '{!! $created_at->diffForHumans() !!}')
            ->editColumn('updated_at', '{!! $updated_at->diffForHumans() !!}')
            ->editColumn('approved_at', '{!! $approved_at->diffForHumans() !!}')
            ->editColumn('expire_at', '{!! $expire_at->diffForHumans() !!}')
            ->editColumn('title', '{!! str_limit($title, 60) !!}')
            ->make(true);
    }
}
