<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */

namespace App\Http\Controllers\Admin\Post;

use App\Http\Controllers\Controller;
use App\Jobshunt\Helpers\ResizeHelper;
use App\Jobshunt\Models\Category;
use App\Jobshunt\Models\Post;
use Carbon\Carbon;
use Illuminate\Http\Request;

class UpdateController extends Controller
{

    /**
     * @param $id
     * @return \BladeView|bool|\Illuminate\View\View
     */
    public function getEdit($id)
    {
        $post = Post::whereId($id)->with('user', 'category', 'type')->firstOrFail();
        $title = 'Editing Post';

        return view('admin.post.edit', compact('post', 'title'));
    }

    /**
     * @param Request $request
     * @return string
     */
    public function postReApprove(Request $request)
    {
        $post = Post::whereId($request->get('id'))->firstOrFail();
        $post->expire_at = Carbon::now()->addDays((int)siteSettings('numberOfDays'));
        $post->save();

        return 'Re-Approved';
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postEdit(Request $request)
    {
        $post = Post::whereId($request->route('id'))->firstOrFail();
        if ($request->get('delete')) {
            $post->delete();

            return redirect()->route('admin.posts')->with('flashSuccess', 'Post is now deleted permanently');
        }
        if (Category::whereId($request->get('category'))->count() != 1) {
            return redirect()->back()->with('flashError', t('Invalid category'));
        }

        if ($request->get('tags')) {
            $tags = implode(',', $request->get('tags'));
        } else {
            $tags = null;
        }
        $slug = str_slug($request->get('title'));
        if (!$slug) {
            $slug = str_random(8);
        }
        $post->title = $request->get('title');
        $post->slug = $slug;
        $post->description = $request->get('description');
        $post->apply_to = $request->get('apply_to');
        $post->category_id = $request->get('category');
        $post->post_type_id = $request->get('job_type');
        $post->tags = $tags;
        $post->save();

        return redirect()->back()->with('flashSuccess', 'Image is now updated');
    }
}