<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */

namespace App\Http\Controllers\Admin\User;

use App\Http\Controllers\Controller;
use App\Jobshunt\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;

class UpdateController extends Controller
{
    /**
     * @param $id
     * @return \BladeView|bool|\Illuminate\View\View
     */
    public function getEdit($id)
    {
        $user = User::whereId($id)->with('posts')->firstOrFail();
        $title = sprintf('Editing User %s (%s)', $user->fullname, $user->username);

        return view('admin.user.edit', compact('user', 'title'));
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postAddUser(Request $request)
    {
        $this->validate($request, [
            'username' => 'required|alpha_num|unique:users',
            'fullname' => 'required',
            'email'    => 'required|unique:users',
            'password' => 'required|min:6',
        ]);

        $user = new User();
        $user->username = $request->get('username');
        $user->fullname = $request->get('fullname');
        $user->email = $request->get('email');
        $user->password = bcrypt($request->get('password'));
        $user->confirmed_at = Carbon::now();
        $user->save();

        return redirect()->back()->with('flashSuccess', 'User is now added');
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function postEdit(Request $request)
    {
        $this->validate($request, [
            'fullname'   => 'required',
            'email'      => 'required|email',
            'url'        => 'url',
            'tw_url'        => 'url',
            'permission' => 'required',
            'delete'     => 'boolean',
        ]);
        $user = User::whereId($request->route('id'))->firstOrFail();
        if ($request->get('delete')) {
            $user->posts()->delete();
            $user->delete();

            return redirect()->route('admin.users')->with('flashSuccess', 'User is now deleted');
        }

        $user->fullname = $request->get('fullname');
        $user->email = $request->get('email');
        $user->about = $request->get('about');
        $user->url = $request->get('url');
        $user->tw_url = $request->get('tw_url');
        $user->permission = $request->get('permission');

        $user->save();

        return redirect()->back()->with('flashSuccess', 'User is now update');
    }

    /**
     * @param Request $request
     * @return string
     */
    public function postApprove(Request $request)
    {
        $user = User::whereId($request->get('id'))->firstOrFail();
        if ($request->get('approve') == 1) {
            $user->confirmed_at = Carbon::now();
            $user->save();

            return 'Approved';
        }
        if ($request->get('approve') == 0) {
            $user->delete();

            return 'Deleted';
        }
    }
}
