<?php

namespace App\Http\Requests\Post;

use App\Http\Requests\Request;
use App\Jobshunt\Repository\PostsRepositoryInterface;

class EditRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(PostsRepositoryInterface $post)
    {
        if (!auth()->check()) {
            return false;
        }

        $post = $post->getById($this->route('id'));

        if (!$post || auth()->user()->id !== $post->user_id) {
            return false;
        }

        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        switch ($this->method()) {
            case 'GET': {
                return [];
            }
            case 'POST': {
                return [
                    'title'       => ['required'],
                    'description' => ['required'],
                    'apply_to'    => ['required'],
                    'is_remote'   => ['boolean'],
                    'job_type'    => ['required', 'exists:post_types,id'],
                    'category'    => ['required', 'exists:categories,id'],
                ];
            }
        }
    }

    public function forbiddenResponse()
    {
        return redirect()->route('gallery')->with('flashError', t('You are not allowed'));
    }
}
