<?php

namespace App\Jobshunt\Events;

use App\Jobshunt\Repository\PostsRepositoryInterface;
use App\Events\Event;
use Illuminate\Queue\SerializesModels;
use Illuminate\Session\Store;


class PostViewHandler extends Event
{
    use SerializesModels;

    /**
     * @param PostResponseEvent $post
     * @param Store $session
     */
    public function __construct(PostsRepositoryInterface $post, Store $session)
    {
        $this->session = $session;
        $this->images = $post;
    }

    /**
     * @param $image
     */
    public function handle($image)
    {
        if (!$this->hasViewedTrick($image)) {
            $image = $this->images->incrementViews($image);
            $this->storeViewedTrick($image);
        }
    }

    /**
     * @param $image
     * @return bool
     */
    protected function hasViewedTrick($image)
    {
        return array_key_exists($image->id, $this->getViewedTricks());
    }

    /**
     * Get the users viewed trick from the session.
     *
     * @return array
     */
    protected function getViewedTricks()
    {
        return $this->session->get('viewed_images', []);
    }

    /**
     * @param $image
     */
    protected function storeViewedTrick($image)
    {

        $key = 'viewed_images.' . $image->id;

        $this->session->put($key, time());
    }
}