<?php
use App\Jobshunt\Models\Category;
use App\Jobshunt\Models\PostType;
use Illuminate\Support\Facades\Cache;

/**
 * @param $string
 * @return string
 */
function t($string)
{
    return trans('text.' . $string, [], null, session('my.locale'));
}

/**
 * @return int
 */
function perPage()
{
    return 20;
}

/**
 * @param $request
 * @return mixed
 */
function siteSettings($request)
{
    return Cache::rememberForever($request, function () use ($request) {
        $request = DB::table('sitesettings')->whereOption($request)->first();

        return $request->value;
    });
}

/**
 * @param        $email
 * @param int $s
 * @param string $d
 * @param string $r
 * @return string
 */
function get_gravatar($email, $s = 80, $d = 'mm', $r = 'g')
{
    $url = '//www.gravatar.com/avatar/';
    $url .= md5(strtolower(trim($email)));
    $url .= "?s=$s&d=$d&r=$r";

    return $url;
}

/**
 * @param null $slug
 * @return mixed
 */
function getCategoryName($slug = null)
{
    $name = Cache::rememberForever('category_' . $slug, function () use ($slug) {
        $category = Category::select('name')->whereSlug($slug)->first();
        if ($category) {
            return $category->name;
        }
    });

    return $name;
}

/**
 * @param null $slug
 * @return mixed
 */
function getPostTypeName($slug = null)
{
    $name = Cache::rememberForever('post_type_' . $slug, function () use ($slug) {
        $category = PostType::select('name')->whereSlug($slug)->first();
        if ($category) {
            return $category->name;
        }
    });

    return $name;
}

/**
 * @param null $text
 * @return string
 */
function parseDown($text = null)
{
    return Parsedown::instance()
        ->setMarkupEscaped(true)# escapes markup (HTML)
        ->text($text);
}

/**
 * @return mixed
 */
function getPopular()
{
    return Cache::remember('getPopular', 10, function () {
        return \App\Jobshunt\Models\Post::approved()->orderBy('views', 'desc')->limit(12)->get();
    });
}

/**
 * @param array $except
 * @return string
 */
function query_params($except = [])
{
    $query = Input::query();

    if (!is_array($except)) {
        $except = [$except];
    }

    foreach ($except as $key => $value) {
        if (is_string($key)) {
            $query[$key] = $value;
        } else {
            unset($query[$value]);
        }
    }

    return (http_build_query($query));
}

/**
 * @param $lang
 * @return string
 */
function langDecode($lang)
{
    switch ($lang) {
        case 'af':
            return 'kaans';
        case 'ak':
            return 'Akan';
        case 'sq':
            return 'Albanian';
        case 'am':
            return 'Amharic';
        case 'ar':
            return 'Arabic';
        case 'hy':
            return 'Armenian';
        case 'az':
            return 'Azerbaijani';
        case 'eu':
            return 'Basque';
        case 'be':
            return 'Belarusian';
        case 'bem':
            return 'Bemba';
        case 'bn':
            return 'Bengali';
        case 'bh':
            return 'Bihari';
        case 'xx-bork':
            return 'Bork, bork, bork!';
        case 'bs':
            return 'Bosnian';
        case 'br':
            return 'Breton';
        case 'bg':
            return 'Bulgarian';
        case 'km':
            return 'Cambodian';
        case 'ca':
            return 'Catalan';
        case 'chr':
            return 'Cherokee';
        case 'ny':
            return 'Chichewa';
        case 'zh-CN':
            return 'Chinese (Simplified)';
        case 'zh-TW':
            return 'Chinese (Traditional)';
        case 'co':
            return 'Corsican';
        case 'hr':
            return 'Croatian';
        case 'cs':
            return 'Czech';
        case 'da':
            return 'Danish';
        case 'nl':
            return 'Dutch';
        case 'xx-elmer':
            return 'Elmer Fudd';
        case 'en':
            return 'English';
        case 'eo':
            return 'Esperanto';
        case 'et':
            return 'Estonian';
        case 'ee':
            return 'Ewe';
        case 'fo':
            return 'Faroese';
        case 'tl':
            return 'Filipino';
        case 'fi':
            return 'Finnish';
        case 'fr':
            return 'French';
        case 'fy':
            return 'Frisian';
        case 'gaa':
            return 'Ga';
        case 'gl':
            return 'Galician';
        case 'ka':
            return 'Georgian';
        case 'de':
            return 'German';
        case 'el':
            return 'Greek';
        case 'gn':
            return 'Guarani';
        case 'gu':
            return 'Gujarati';
        case 'xx-hacker':
            return 'Hacker';
        case 'ht':
            return 'Haitian Creole';
        case 'ha':
            return 'Hausa';
        case 'haw':
            return 'Hawaiian';
        case 'iw':
            return 'Hebrew';
        case 'hi':
            return 'Hindi';
        case 'hu':
            return 'Hungarian';
        case 'is':
            return 'Icelandic';
        case 'ig':
            return 'Igbo';
        case 'id':
            return 'Indonesian';
        case 'ia':
            return 'Interlingua';
        case 'ga':
            return 'Irish';
        case 'it':
            return 'Italian';
        case 'ja':
            return 'Japanese';
        case 'jw':
            return 'Javanese';
        case 'kn':
            return 'Kannada';
        case 'kk':
            return 'Kazakh';
        case 'rw':
            return 'Kinyarwanda';
        case 'rn':
            return 'Kirundi';
        case 'xx-klingon':
            return 'Klingon';
        case 'kg':
            return 'Kongo';
        case 'ko':
            return 'Korean';
        case 'kri':
            return 'Krio (Sierra Leone)';
        case 'ku':
            return 'Kurdish';
        case 'ckb':
            return 'Kurdish (Soran�)';
        case 'ky':
            return 'Kyrgyz';
        case 'lo':
            return 'Laothian';
        case 'la':
            return 'Latin';
        case 'lv':
            return 'Latvian';
        case 'ln':
            return 'Lingala';
        case 'lt':
            return 'Lithuanian';
        case 'loz':
            return 'Lozi';
        case 'lg':
            return 'Luganda';
        case 'ach':
            return 'Luo';
        case 'mk':
            return 'Macedonian';
        case 'mg':
            return 'Malagasy';
        case 'ms':
            return 'Malay';
        case 'ml':
            return 'Malayalam';
        case 'mt':
            return 'Maltese';
        case 'mi':
            return 'Maori';
        case 'mr':
            return 'Marathi';
        case 'mfe':
            return 'Mauritian Creole';
        case 'mo':
            return 'Moldavian';
        case 'mn':
            return 'Mongolian';
        case 'sr-ME':
            return 'Montenegrin';
        case 'ne':
            return 'Nepali';
        case 'pcm':
            return 'Nigerian Pidgin';
        case 'nso':
            return 'Northern Sotho';
        case 'no':
            return 'Norwegian';
        case 'nn':
            return 'Norwegian (Nynorsk)';
        case 'oc':
            return 'Occitan';
        case 'or':
            return 'Oriya';
        case 'om':
            return 'Oromo';
        case 'ps':
            return 'Pashto';
        case 'fa':
            return 'Persian';
        case 'xx-pirate':
            return 'Pirate';
        case 'pl':
            return 'Polish';
        case 'pt-BR':
            return 'Portuguese (Brazil)';
        case 'pt-PT':
            return 'Portuguese (Portugal)';
        case 'pa':
            return 'Punjabi';
        case 'qu':
            return 'Quechua';
        case 'ro':
            return 'Romanian';
        case 'rm':
            return 'Romansh';
        case 'nyn':
            return 'Runyakitara';
        case 'ru':
            return 'Russian';
        case 'gd':
            return 'Scots Gaelic';
        case 'sr':
            return 'Serbian';
        case 'sh':
            return 'Serbo-Croatian';
        case 'st':
            return 'Sesotho';
        case 'tn':
            return 'Setswana';
        case 'crs':
            return 'Seychellois Creole';
        case 'sn':
            return 'Shona';
        case 'sd':
            return 'Sindhi';
        case 'si':
            return 'Sinhalese';
        case 'sk':
            return 'Slovak';
        case 'sl':
            return 'Slovenian';
        case 'so':
            return 'Somali';
        case 'es':
            return 'Spanish';
        case 'es-419':
            return 'Spanish (Latin American)';
        case 'su':
            return 'Sundanese';
        case 'sw':
            return 'Swahili';
        case 'sv':
            return 'Swedish';
        case 'tg':
            return 'Tajik';
        case 'ta':
            return 'Tamil';
        case 'tt':
            return 'Tatar';
        case 'te':
            return 'Telugu';
        case 'th':
            return 'Thai';
        case 'ti':
            return 'Tigrinya';
        case 'to':
            return 'Tonga';
        case 'lua':
            return 'Tshiluba';
        case 'tum':
            return 'Tumbuka';
        case 'tr':
            return 'Turkish';
        case 'tk':
            return 'Turkmen';
        case 'tw':
            return 'Twi';
        case 'ug':
            return 'Uighur';
        case 'uk':
            return 'Ukrainian';
        case 'ur':
            return 'Urdu';
        case 'uz':
            return 'Uzbek';
        case 'vi':
            return 'Vietnamese';
        case 'cy':
            return 'Welsh';
        case 'wo':
            return 'Wolof';
        case 'xh':
            return 'Xhosa';
        case 'yi':
            return 'Yiddish';
        case 'yo':
            return 'Yoruba';
        case 'zu':
            return 'Zulu';
        default:
            return 'English';
    }
}

/**
 * @return array
 */
function languageArray()
{
    return [
        'af',
        'ak',
        'sq',
        'am',
        'ar',
        'hy',
        'az',
        'eu',
        'be',
        'bem',
        'bn',
        'bh',
        'xx-bork',
        'bs',
        'br',
        'bg',
        'km',
        'ca',
        'chr',
        'ny',
        'zh-CN',
        'zh-TW',
        'co',
        'hr',
        'cs',
        'da',
        'nl',
        'xx-elmer',
        'en',
        'eo',
        'et',
        'ee',
        'fo',
        'tl',
        'fi',
        'fr',
        'fy',
        'gaa',
        'gl',
        'ka',
        'de',
        'el',
        'gn',
        'gu',
        'xx-hacker',
        'ht',
        'ha',
        'haw',
        'iw',
        'hi',
        'hu',
        'is',
        'ig',
        'id',
        'ia',
        'ga',
        'it',
        'ja',
        'jw',
        'kn',
        'kk',
        'rw',
        'rn',
        'xx-klingon',
        'kg',
        'ko',
        'kri',
        'ku',
        'ckb',
        'ky',
        'lo',
        'la',
        'lv',
        'ln',
        'lt',
        'loz',
        'lg',
        'ach',
        'mk',
        'mg',
        'ms',
        'ml',
        'mt',
        'mi',
        'mr',
        'mfe',
        'mo',
        'mn',
        'sr-ME',
        'ne',
        'pcm',
        'nso',
        'no',
        'nn',
        'oc',
        'or',
        'om',
        'ps',
        'fa',
        'xx-pirate',
        'pl',
        'pt-BR',
        'pt-PT',
        'pa',
        'qu',
        'ro',
        'rm',
        'nyn',
        'ru',
        'gd',
        'sr',
        'sh',
        'st',
        'tn',
        'crs',
        'sn',
        'sd',
        'si',
        'sk',
        'sl',
        'so',
        'es',
        'es-419',
        'su',
        'sw',
        'sv',
        'tg',
        'ta',
        'tt',
        'te',
        'th',
        'ti',
        'to',
        'lua',
        'tum',
        'tr',
        'tk',
        'tw',
        'ug',
        'uk',
        'ur',
        'uz',
        'vi',
        'cy',
        'wo',
        'xh',
        'yi',
        'yo',
        'zu'
    ];
}

/**
 * @return mixed
 */
function maxUploadSize()
{
    $max_upload = (int)(ini_get('upload_max_filesize'));
    $max_post = (int)(ini_get('post_max_size'));

    return min($max_upload, $max_post);
}

function maxApplyFileUploadSize()
{
    $size = maxUploadSize();
    if ($size >= 5) {
        return 5;
    }
    return $size;
}

/**
 * @return mixed
 */
function siteCategories()
{
    return Cache::rememberForever('categories', function () {
        return Category::orderBy('lft', 'asc')->whereNotIn('id', [1])->get();
    });
}

/**
 * @return mixed
 */
function sitePostTypes()
{
    return Cache::rememberForever('post_types', function () {
        return PostType::orderBy('lft', 'asc')->whereNotIn('id', [1])->get();
    });
}
