@extends('master.index')
@section('content')
    <div class="col-md-9 jobs-container">
        @include('posts.partials.search')
        <div class="row">
            <h1 class="content-heading">{{ ucfirst($user->fullname) }} <small> ( {{ $user->username }} )</small> </h1>
            <div class="profile-list">
                <div class="media profile-content">
                    <div class="media-body">
                        <div class="col-md-2 col-sm-2 col-xs-2 avatar-holder">
                            <a href="{{ route('users.profile', ['username' => $user->username]) }}">
                                <img class="img-responsive" src="{{ Resize::avatar($user,'listingAvatar') }}" alt="{{ $user->fullname }}">
                            </a>
                        </div>
                        <div class="col-md-9 col-sm-9 col-xs-8">
                            <h2 class="media-heading">
                                <a href="{{ route('users.profile', ['username' => $user->username]) }}">{{ $user->fullname }}</a>
                                <small> ( {{ $user->username }} )</small>
                            </h2>
                            <div class="job-info">
                                <ul class="list-inline">
                                    @if($user->url)<li><i class="fa fa-external-link fa-fw"></i><a href="{{ $user->url }}" target="_blank">{{ $user->url }}</a></li>@endif
                                    @if($user->tw_url)<li><i class="fa fa-twitter fa-fw"></i><a href="{{ $user->tw_url }}" target="_blank">{{ $user->tw_url }}</a></li>@endif
                                </ul>
                                @if($user->is_freelancer)<p><a href="{{ route('users.contact', ['username' => $user->username]) }}" class="btn btn-lg btn-success"><i class="fa fa fa-envelope-o fa-fw"></i> {{ t('Contact/Hire Me') }}</a></p>@endif
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            @if($user->about)
                <div class="job-full-description">
                    <div class="media profile-content">
                        <div class="media-body">
                            {!! parseDown($user->about) !!}
                        </div>
                    </div>
                </div>
            @endif
        </div>
        @if($posts->count())
            <div class="row">
                <h2 class="content-heading">{{ sprintf('%s %s', t('Jobs From'), $user->fullname) }}</h2>
                <div class="jobs-list">
                    @foreach($posts as $post)
                        <div class="media job-content">
                            <div class="media-body">
                                <div class="col-md-2 col-sm-2 col-xs-2 avatar-holder">
                                    <a href="{{ route('users.profile', ['username' => $post->user->username]) }}">
                                        <img class="img-responsive" src="{{ Resize::avatar($post->user,'listingAvatar') }}" alt="{{ $post->user->fullname }}">
                                    </a>
                                </div>
                                <div class="col-md-9 col-sm-9 col-xs-9">
                                    <h3 class="media-heading">
                                        <a href="{{ route('posts.main',['id' => $post->id, 'slug' => $post->slug]) }}">{{ $post->title }}</a>
                                    </h3>
                                    <div class="job-info">
                                        <p><i>{{ t('by') }}: <a href="{{ route('users.profile', ['username' => $post->user->username]) }}">{{ $post->user->fullname }}</a></i>
                                            @if(auth()->check() && auth()->user()->id == $post->user->id)
                                                | <a href="{{ route('posts.edit', ['id' => $post->id, 'slug' => $post->slug]) }}">{{ t('Edit') }}</a>
                                            @endif
                                        </p>
                                        @if($post->tags)
                                            <ul class="list-inline tags-list">
                                                @foreach(explode(',',$post->tags) as $tag)
                                                    <li><a href="{{ route('posts.list', ['tag' => $tag]) }}"><span class="label label-default"><i class="fa fa-tag"></i> {{ $tag }}</span></a></li>
                                                @endforeach
                                            </ul>
                                        @endif
                                        <div>
                                            <a href="{{ route('posts.list',['category' => $post->category->slug]) }}"><span class="label label-default"><i class="fa fa-th-large"></i> {{ $post->category->name }}</span></a>
                                            <a href="{{ route('posts.list',['type' => $post->type->slug]) }}"><span class="label label-default"><i class="fa fa-list-ul"></i> {{ $post->type->name }}</span></a>
                            <span class="country-tag">
                                @if($post->is_remote)
                                    <a href="{{ route('posts.list', ['remote' => true]) }}"><span class="label label-default"><i class="fa fa-globe"></i> {{ t('Remote / Anywhere') }}</span></a>
                                @else
                                    @if($post->city)<a href="{{ route('posts.list', ['city' => $post->city]) }}"><span class="label label-default"><i class="fa fa-map-marker"></i> {{ $post->city }}</span></a>@endif
                                    @if($post->state)<a href="{{ route('posts.list', ['state' => $post->state]) }}"><span class="label label-default"><i class="fa fa-location-arrow"></i> {{ $post->state }}</span></a>@endif
                                    @if($post->country)<a href="{{ route('posts.list', ['country' => $post->country]) }}"><span class="label label-default"><i class="fa fa-globe"></i> {{ $post->country }}</span></a>@endif
                                @endif
                            </span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
        @endif
    </div>
    @include('posts.partials.sidebar')
    <div class="clearfix"></div>
    {!! $posts->appends(Input::except('page'))->render() !!}
@endsection